"""Simple water flow example using ANUGA

Water driven up a linear slope and time varying boundary,
similar to a beach environment
"""


#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

from anuga.abstract_2d_finite_volumes.mesh_factory import rectangular_cross
from anuga.shallow_water import Domain
from anuga.shallow_water import Reflective_boundary
from anuga.shallow_water import Dirichlet_boundary
from anuga.shallow_water import Time_boundary
from anuga.shallow_water import Transmissive_boundary

from Numeric import zeros, Float
from RandomArray import normal, seed

seed(13, 17) # Ensure random number sequence is reproducible

#------------------------------------------------------------------------------
# Setup computational domain
#------------------------------------------------------------------------------

points, vertices, boundary = rectangular_cross(90, 30,
                                               len1=3.0,
                                               len2=1.0) # Basic mesh

domain = Domain(points, vertices, boundary) # Create domain
domain.set_name('sensitivity')              # Output to file runup.sww
domain.set_datadir('.')                     # Use current directory for output
domain.tight_slope_limiters = 1
domain.beta_h = 0

#------------------------------------------------------------------------------
# Setup initial conditions
#------------------------------------------------------------------------------

def topography(x,y):

    N = len(x)
    z = zeros(N, Float)


    for i in range(N):
        # linear bed slope            
        z[i] = -x[i]/15

        # IID noise
        z[i] += normal(0.0, 0.01)
        
    return z

domain.set_quantity('elevation', topography) # Use function for elevation
domain.set_quantity('friction', 0.01)        # Constant friction 
domain.set_quantity('stage', -.4)            # Constant negative initial stage


#------------------------------------------------------------------------------
# Setup boundary conditions
#------------------------------------------------------------------------------

from math import sin, pi, exp
Br = Reflective_boundary(domain)      # Solid reflective wall
Bt = Transmissive_boundary(domain)    # Continue all values on boundary 
Bd = Dirichlet_boundary([-0.2,0.,0.]) # Constant boundary values
Bw = Time_boundary(domain=domain,     # Time dependent boundary  
                   f=lambda t: [(.1*sin(t*2*pi)-0.1) , 0.0, 0.0])

# Associate boundary tags with boundary objects
domain.set_boundary({'left': Br, 'right': Bw, 'top': Br, 'bottom': Br})


import time
t0 = time.time()
#------------------------------------------------------------------------------
# Evolve system through time
#------------------------------------------------------------------------------

for t in domain.evolve(yieldstep = 0.1, finaltime = 50.0):
    domain.write_time()

print 'That took %.2f seconds' %(time.time()-t0)

